@@ -1,4 +1,4 @@
-# Copyright 2006, 2013 Reahl Software Services (Pty) Ltd. All rights reserved.
+# Copyright 2013, 2014 Reahl Software Services (Pty) Ltd. All rights reserved.
 #
 #    This file is part of Reahl.
 #
@@ -25,8 +25,7 @@ description of the package.
 
 """ 
 
-from __future__ import unicode_literals
-from __future__ import print_function
+from __future__ import print_function, unicode_literals, absolute_import, division
 
 __import__('pkg_resources').declare_namespace(__name__)
 
