@@ -1,6 +1,5 @@
 
-from __future__ import unicode_literals
-from __future__ import print_function
+from __future__ import print_function, unicode_literals, absolute_import, division
 from reahl.doc.examples.features.tabbedpanel.tabbedpanel import TabbedPanelUI
 
 web.site_root = TabbedPanelUI
