@@ -1,6 +1,5 @@
 
-from __future__ import unicode_literals
-from __future__ import print_function
+from __future__ import print_function, unicode_literals, absolute_import, division
 from reahl.doc.examples.tutorial.addressbook1.addressbook1 import AddressBookUI
 
 web.site_root = AddressBookUI
