@@ -1,5 +1,4 @@
 
 # In production, you'd want this to be set so something sensible:
-from __future__ import unicode_literals
-from __future__ import print_function
+from __future__ import print_function, unicode_literals, absolute_import, division
 accounts.admin_email = 'admin@example.org'  
