@@ -1,7 +1,6 @@
 
 
-from __future__ import unicode_literals
-from __future__ import print_function
+from __future__ import print_function, unicode_literals, absolute_import, division
 from reahl.doc.examples.tutorial.login2.login2 import LoginUI
 
 web.site_root = LoginUI
